<?php

namespace Drupal\custom_tests;

use Drupal\Core\File\FileSystemInterface;

/**
 * Test Suite Services.
 */
class CustomTestsResourceService {

  /**
   * The file system service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * CustomTestsResourceService constructor.
   *
   * @param \Drupal\Core\File\FileSystemInterface $fileSystem
   *   The file system interface.
   */
  public function __construct(
        FileSystemInterface $fileSystem
    ) {
    $this->fileSystem = $fileSystem;
  }

  /**
   * Gets the array of files to create classes with.
   *
   * @return array
   *   The array of files to create classes with.
   */
  public function getTests() {
    $customTestsArray = [];
    $customTests = $this->getResource();
    foreach ($customTests as $file) {
      $className = basename($file, '.php');
      $class = explode(".", $className)[0];
      $customTestsArray[$class] = $class;
    }

    return $customTestsArray;
  }

  /**
   * Gets the array of files to create classes with.
   *
   * @return array
   *   The array of files to create classes with.
   */
  public function getResource() {
    $customTestsArray = [];
    $testsuite = DIRECTORY_SEPARATOR . 'testsuite' . DIRECTORY_SEPARATOR . 'modules';
    $path = $this->fileSystem->realpath('modules') . DIRECTORY_SEPARATOR . 'contrib' . $testsuite;
    if (is_dir($path)) {
      $scan = scandir($path);
      unset($scan[array_search('.', $scan, TRUE)]);
      unset($scan[array_search('..', $scan, TRUE)]);
      foreach ($scan as $module) {
        if (is_dir($path . DIRECTORY_SEPARATOR . $module)) {
          $testsPath = $path . DIRECTORY_SEPARATOR . $module . DIRECTORY_SEPARATOR . 'src' . DIRECTORY_SEPARATOR . 'CustomTSTests' . DIRECTORY_SEPARATOR;
          if (is_dir($testsPath)) {
            $customTestsArray = glob($testsPath . '*.php');
          }
        }
      }
    }

    return $customTestsArray;
  }

}
